apache-airflow-providers-nomad
=============================================

Release: 0.0.4

Airflow Nomad Provider
------------------------------------

.. **Note**:
..
..     *This project is not part of the official* `Apache Airflow <https://airflow.apache.org/>`__ *release*

.. note:: This project is not part of the official `Apache Airflow <https://airflow.apache.org/>`__ release

Provider for `HashiCorp Nomad <https://developer.hashicorp.com/nomad>`__ clusters running Airflow tasks.

For details see the `Project Documentation <https://juditnovak.github.io/airflow-provider-nomad/>`__
